@@ -3,7 +3,7 @@
 .onAttach <- function(lib, pkg)
 {
   packageStartupMessage('**************************************************************')
-  packageStartupMessage('*                          swissdd 0.0.9                     *')
+  packageStartupMessage('*                          swissdd 1.0.1                     *')
   packageStartupMessage('*                     provided by politan.ch                 *')
   packageStartupMessage('*                                                            *')
   packageStartupMessage('*                                                            *')
@@ -15,12 +15,21 @@
 
 # suppress notes
 
-utils::globalVariables(c("id", "resultat",
-                         "res","geoid","langKey",
-                         "yes","kantonname",
-                         "results2","geoLevelnummer",
-                         "geoname","district_id",
-                         "geoLevelname","text","ktid"))
+utils::globalVariables(c("id", "resultat","res","geoid",
+                         "canton_id","canton_name",
+                         "district_id","district_name",
+                         "mun_id","mun_name",
+                         "langKey",
+                         "yes",
+                         # "kantonname",
+                         "results2",
+                         "geoLevelnummer",
+                         # "geoname",
+                         "jaStimmenInProzent",
+                         "cor","cov","correlation",
+                         # "geoLevelname",
+                         "text"#,"ktid"
+                         ))
 
 
 
